/* build.c */

#include "config.h"

#include <stdio.h>
#include <errno.h>
#include <ftw.h>
#include <string.h>

#include <db.h>

#include <sys/types.h>

#include "md5.h"
#include "wa.h"


static DB *dbp;
static int verbose = 0;
static char *database_path = "tmp.db";




static int
insert_object(const char *path,
	      const struct stat *sp,
	      int f,
	      struct FTW * fp)
{
    int err;
    wa_fileinfo_t fib;
    DBT key, data;


    if (sp == NULL)
	return 0;
    
    memset(&fib, 0, sizeof(fib));
    memset(&key, 0, sizeof(key));
    memset(&data, 0, sizeof(data));

    fib.statbuf = *sp;
    data.size = sizeof(wa_fileinfo_t);
    data.data = &fib;
    
    key.size = strlen(path)+1;
    key.data = (char *) path;
    
    if (f == FTW_F)
	md5_file(path, &fib.digest);
    
    err = dbp->put(dbp, NULL, &key, &data, 0);
    if (err)
	fprintf(stderr, "db_put: %s: %s\n", path, strerror(errno));

    if (verbose)
	puts(path);
    
    return 0;
}


static char *argv0;


static void
usage(FILE *fp)
{
    fprintf(fp, "Usage: %s [-v] DB path [... path]\n", argv0);
}



int
main(int argc,
     char *argv[])
{
    int i, err;
    

    argv0 = argv[0];
    
    for (i = 1; i < argc && argv[i][0] == '-'; i++)
	switch (argv[i][1])
	{
	  case 'v':
	    verbose = 1;
	    break;

	  default:
	    fprintf(stderr, "%s: %s: invalid command line option\n",
		    argv[0], argv[i]);
	    usage(stderr);
	    exit(1);
	}

    if (i == argc)
    {
	fprintf(stderr, "%s: missing database argument\n", argv[0]);
	exit(1);
    }

    database_path = argv[i++];
    
    err = db_open(database_path, DB_BTREE, DB_CREATE,
		  0664, NULL, NULL, &dbp);
    if (err)
    {
	fprintf(stderr, "db_open: %s: %s\n", 
		database_path, strerror(err));
	exit(1);
    }

    for (; i < argc; i++)
	nftw(argv[i], insert_object, 200, FTW_PHYS+FTW_MOUNT+FTW_CHDIR);

    err = dbp->close(dbp, 0);
    
    exit(0);
}
	
		   
