/* dump.c */

#include "config.h"

#include <stdio.h>
#include <errno.h>
#include <string.h>

#include <db.h>

#include <sys/types.h>
#include <sys/stat.h>

#include "md5.h"
#include "wa.h"

static DB *dbp;
static int verbose = 0;
static char *database_path = "tmp.db";



static int
print_object(const char *path,
	     wa_fileinfo_t *fip)
{
    puts(path);
    return 0;
}


static char *argv0;


static void
usage(FILE *fp)
{
    fprintf(fp, "Usage: %s [-v] DB\n", argv0);
}



int
main(int argc,
     char *argv[])
{
    int i, err;
    DBC *cursor;
    DBT key, data;
    

    argv0 = argv[0];
    
    for (i = 1; i < argc && argv[i][0] == '-'; i++)
	switch (argv[i][1])
	{
	  case 'v':
	    verbose = 1;
	    break;

	  default:
	    fprintf(stderr, "%s: %s: invalid command line option\n",
		    argv[0], argv[i]);
	    usage(stderr);
	    exit(1);
	}

    if (i+1 != argc)
    {
	fprintf(stderr, "%s: missing database argument\n", argv[0]);
	exit(1);
    }
	
    database_path = argv[i++];
    
    err = db_open(database_path, DB_UNKNOWN, DB_RDONLY, 0, NULL, NULL, &dbp);
    if (err)
    {
	fprintf(stderr, "db_open: %s: %s\n", database_path, strerror(err));
	exit(1);
    }

	   
    err = dbp->cursor(dbp, NULL, &cursor, 0);
    if (err)
    {
	fprintf(stderr, "db_cursor: %s\n", strerror(err));
	goto Fail;
    }

    memset(&key, 0, sizeof(key));
    memset(&data, 0, sizeof(data));
    

    while ((err = cursor->c_get(cursor, &key, &data, DB_NEXT)) == 0)
    {
	print_object(key.data, data.data);
    }

    if (err > 0 && err != DB_NOTFOUND)
    {
	fprintf(stderr, "c_get: %s\n", strerror(err));
	goto Fail;
    }
    
    err = dbp->close(dbp, 0);
    exit(0);

  Fail:
    err = dbp->close(dbp, 0);
    exit(1);
}
	
		   
