/* mkindex.c */

#include "config.h"

#include <stdio.h>
#include <errno.h>
#include <string.h>

#include <db.h>

#include <sys/types.h>
#include <sys/stat.h>

#include "md5.h"
#include "wa.h"

static DB *dbp;
static int verbose = 0;
static char *database_path = "tmp.db";

static char *argv0;


static void
usage(FILE *fp)
{
    fprintf(fp, "Usage: %s [-v] MAINDB INDEXDB\n", argv0);
}



int
main(int argc,
     char *argv[])
{
    int i, err;
    DB *idbp;
    DB_INFO dbi;
    DBC *cursor;
    DBT key, data;
    char *index_db_path;
    

    argv0 = argv[0];
    
    for (i = 1; i < argc && argv[i][0] == '-'; i++)
	switch (argv[i][1])
	{
	  case 'v':
	    verbose = 1;
	    break;

	  default:
	    fprintf(stderr, "%s: %s: invalid command line option\n",
		    argv[0], argv[i]);
	    usage(stderr);
	    exit(1);
	}

    if (i+2 != argc)
    {
	fprintf(stderr, "%s: missing database argumentsa\n", argv[0]);
	exit(1);
    }
	
    database_path = argv[i++];
    index_db_path = argv[i++];
    
    err = db_open(database_path, DB_UNKNOWN, DB_RDONLY, 0, NULL, NULL, &dbp);
    if (err)
    {
	fprintf(stderr, "db_open: %s: %s\n", database_path, strerror(err));
	exit(1);
    }

    memset(&dbi, 0, sizeof(dbi));
    dbi.flags |= DB_DUP;
    
    err = db_open(index_db_path, DB_BTREE, DB_CREATE, 0664,
		  NULL, &dbi, &idbp);
    if (err)
    {
	fprintf(stderr, "db_open: %s: %s\n", index_db_path, strerror(err));
	exit(1);
    }

	   
    err = dbp->cursor(dbp, NULL, &cursor, 0);
    if (err)
    {
	fprintf(stderr, "db_cursor: %s\n", strerror(err));
	goto Fail;
    }

    memset(&key, 0, sizeof(key));
    memset(&data, 0, sizeof(data));
    

    while ((err = cursor->c_get(cursor, &key, &data, DB_NEXT)) == 0)
    {
	DBT ikey;
	char *file;

	
	file = strrchr(key.data, '/');
	if (!file)
	    file = key.data;
	else
	    ++file;

	memset(&ikey, 0, sizeof(ikey));
	ikey.data = file;
	ikey.size = strlen(file)+1;
	
	idbp->put(idbp, NULL, &ikey, &key, 0);
    }

    if (err > 0 && err != DB_NOTFOUND)
    {
	fprintf(stderr, "c_get: %s\n", strerror(err));
	goto Fail;
    }
    
    err = idbp->close(idbp, 0);
    err = dbp->close(dbp, 0);
    exit(0);

  Fail:
    err = idbp->close(idbp, 0);
    err = dbp->close(dbp, 0);
    exit(1);
}
	
		   
